==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythgallery/i18n/mythgallery_ca.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="unfinished">Creat:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="unfinished">Modificat:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="unfinished">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Amplada</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="unfinished">píxels</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished">Alçada</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="unfinished">Nombre de Pixels</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished">megapíxels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="unfinished">Angle de rotació</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished">graus</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importar imatges?</translation>
    </message>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>No he trovat res per a importar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Directori que conté les imatges</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Aquest directori ha d&apos;existir i s&apos;hi ha de tenir accès de lectura.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Camí per a importar imatges</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Tipus de transició</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tipus de fons</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Aquest és el nombre de segons per visualitzar cada imatge.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Configuració de MythGallery</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Camins separats per dos punts (&apos;:&apos;). Si el camí és un directori, el contingut serà copiat, si és un programa, serà executat.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Aquest és el tipus de transició entre imatges en el mode de presentació.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>És el tipus de fons per a cada imatge en el mode de una sola imatge.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Temps d&apos;espera</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Alçada</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Nombre de Pixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Angle de rotació</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>píxels</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapíxels</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>graus</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Creat:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modificat:</translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythgallery/i18n/mythgallery_ca.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Creat:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Modificat:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Amplada</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">píxels</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Alçada</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Nombre de Pixels</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">megapíxels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Angle de rotació</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">graus</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importar imatges?</translation>
    </message>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>No he trovat res per a importar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Directory &apos;%1&apos; does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery failed to load theme, see console for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected device is no longer available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta Data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marking...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Marked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Current File or Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 folder, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Marked Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting %1 images and folders, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving marked images...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying marked images...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Directori que conté les imatges</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Aquest directori ha d&apos;existir i s&apos;hi ha de tenir accès de lectura.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Camí per a importar imatges</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Tipus de transició</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tipus de fons</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Aquest és el nombre de segons per visualitzar cada imatge.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation type="obsolete">Configuració de MythGallery</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Camins separats per dos punts (&apos;:&apos;). Si el camí és un directori, el contingut serà copiat, si és un programa, serà executat.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Aquest és el tipus de transició entre imatges en el mode de presentació.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>És el tipus de fons per a cada imatge en el mode de una sola imatge.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Temps d&apos;espera</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store thumbnails in image directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, thumbnails are stored in &apos;.thumbcache&apos; directories within the above directory. If cleared, they are stored in your home directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recurse into directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to let the slideshow recurse into sub-directories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlay caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the number of seconds to show a caption on top of a full size picture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort order when browsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the sort order for the displayed picture thumbnails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration of OpenGL Transition (milliseconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (Slideshow)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (General)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Amplada</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Alçada</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Nombre de Pixels</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Angle de rotació</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">píxels</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">megapíxels</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">graus</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Creat:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Modificat:</translation>
    </message>
</context>
</TS>
